==> ettercap-0.5.2.tar.gz: ettercap-0.5.2/src/ec_dissector_pop.c <==
/*
    ettercap -- dissector POP3 -- TCP 110

    Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include "include/ec_main.h"

#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#include "include/ec_dissector.h"
#include "include/ec_inet_structures.h"
#include "include/ec_error.h"

#ifdef DEBUG
   #include "include/ec_debug.h"
#endif

// protos

FUNC_DISSECTOR(Dissector_pop);

// --------------------


FUNC_DISSECTOR(Dissector_pop)
{

   TCP_header *tcp;
   u_char *payload;
   ONLY_CONNECTION;

   tcp = (TCP_header *) data;

   if (ntohs(tcp->source) == SERV_PORT) return 0;           // skip server messages...

   payload = (char *)((int)tcp + tcp->doff * 4);

   if ( !strncasecmp(payload, "USER", 4) )
   {
      char user[25];
      #ifdef DEBUG
         Debug_msg("\tDissector_POP USER");
      #endif
      strncpy(user, payload + strlen("USER ") , 25 );
      strcpy(data_to_ettercap->user, user);
   }

   if ( !strncasecmp(payload, "PASS", 4) )
   {
      char pass[25];
      #ifdef DEBUG
         Debug_msg("\tDissector_POP PASS");
      #endif
      strncpy(pass, payload + strlen("PASS ") , 25 );
      strcpy(data_to_ettercap->pass, pass);
   }

   if ( !strncasecmp(payload, "APOP", 4) )
   {
      char user[25];
      char *p;
      #ifdef DEBUG
         Debug_msg("\tDissector_POP APOP");
      #endif

      strncpy(user, strtok(payload + strlen("APOP "), " ") , 25 );
      sprintf(data_to_ettercap->user, "%s\n", user);
      strcpy(data_to_ettercap->pass, "\n");
      p = strtok(NULL, " ");
      sprintf(data_to_ettercap->info, "Authenticated with APOP %s\n", (p) ? p : "");
   }

   return 0;
}


/* EOF */

==> ettercap_0.6.4.orig.tar.gz: ettercap-0.6.4/src/ec_dissector_pop.c <==
/*
    ettercap -- dissector POP3 -- TCP 110

    Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

    $Id: ec_dissector_pop.c,v 1.5 2001/12/09 20:24:51 alor Exp $
*/

#include "include/ec_main.h"

#include "include/ec_dissector.h"
#include "include/ec_inet_structures.h"
#include "include/ec_error.h"

// protos

FUNC_DISSECTOR(Dissector_pop);

// --------------------


FUNC_DISSECTOR(Dissector_pop)
{

   TCP_header *tcp;
   u_char *payload;
   ONLY_CONNECTION;

   tcp = (TCP_header *) data;

   if (ntohs(tcp->source) == SERV_PORT) return 0;     // skip server messages...
   if (data_to_ettercap->datalen == 0) return 0;      // no data...

   payload = (char *)((int)tcp + tcp->doff * 4);

   if ( !strncasecmp(payload, "USER", 4) )
   {
      #ifdef DEBUG
         Debug_msg("\tDissector_POP USER");
      #endif
      strlcpy(data_to_ettercap->user, payload + strlen("USER "), sizeof(data_to_ettercap->user));
   }

   if ( !strncasecmp(payload, "PASS", 4) )
   {
      #ifdef DEBUG
         Debug_msg("\tDissector_POP PASS");
      #endif
      strlcpy(data_to_ettercap->pass, payload + strlen("PASS "), sizeof(data_to_ettercap->pass));
   }

   if ( !strncasecmp(payload, "APOP", 4) )
   {
      char *p;
      #ifdef DEBUG
         Debug_msg("\tDissector_POP APOP");
      #endif

      p = strtok(payload + strlen("APOP "), " ");
      if (p)
      {
         snprintf(data_to_ettercap->user, sizeof(data_to_ettercap->user), "%s\n", p);
         sprintf(data_to_ettercap->pass, "\n");
         p = strtok(NULL, " ");
         snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "Authenticated with APOP %s\n", (p) ? p : "");
      }
   }

   return 0;
}


/* EOF */
